#!/usr/bin/env python

"""
Copyright (C) 2007 Trolltech ASA. All rights reserved.

This file is part of the documentation of Qt. It was originally
published as part of Qt Quarterly.

This file may be used under the terms of the GNU General Public License
version 2.0 as published by the Free Software Foundation or under the
terms of the Qt Commercial License Agreement. The respective license
texts for these are provided with the open source and commercial
editions of Qt.

If you are unsure which license is appropriate for your use, please
review the following information:
http://www.trolltech.com/products/qt/licensing.html or contact the
sales department at sales@trolltech.com.

This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
"""

import sys
from PyQt4.QtCore import *
from PyQt4.QtGui import *
from PyQt4.QtNetwork import *

class Window(QWidget):

    def __init__(self, parent = None):
    
        QWidget.__init__(self, parent)
        
        self.http = QHttp()
        self.connect(self.http, SIGNAL("done(bool)"), self.updateForm)
        
        self.outputLabel = QLabel()
        self.outputLabel.setFrameShape(QFrame.StyledPanel)
        self.equationEditor = QTextEdit()
        
        buttonBox = QDialogButtonBox()
        self.clearButton = buttonBox.addButton(self.tr("&Clear"),
            QDialogButtonBox.ResetRole)
        self.updateButton = buttonBox.addButton(self.tr("&Update"),
            QDialogButtonBox.ApplyRole)
        
        self.connect(self.clearButton, SIGNAL("clicked()"), self.clearForm)
        self.connect(self.updateButton, SIGNAL("clicked()"), self.fetchImage)
        
        layout = QVBoxLayout()
        layout.setMargin(4)
        layout.setSpacing(4)
        layout.addWidget(self.outputLabel, 1)
        layout.addWidget(self.equationEditor)
        layout.addWidget(buttonBox)
        self.setLayout(layout)
        
        self.setWindowTitle(self.tr("MathTran Equation Viewer"))
    
    def clearForm(self):
    
        self.outputLabel.setPixmap(QPixmap())
        self.equationEditor.clear()
    
    def fetchImage(self):
    
        self.clearButton.setEnabled(False)
        self.updateButton.setEnabled(False)
        self.equationEditor.setReadOnly(True)
        
        url = QUrl()
        url.setPath("/cgi-bin/mathtran")
        url.setQueryDelimiters("=", ";")
        url.addQueryItem("D", "3");
        url.addQueryItem("tex", str(QUrl.toPercentEncoding(
                         self.equationEditor.toPlainText())))
        
        self.http.setHost("mathtran.org")
        self.http.get(url.toString())
    
    def updateForm(self, error):
    
        self.clearButton.setEnabled(True)
        self.updateButton.setEnabled(True)
        self.equationEditor.setReadOnly(False)
        
        if error:
            return
        
        image = QImage()
        if not image.loadFromData(self.http.readAll()):
            return
        
        pixmap = QPixmap.fromImage(image)
        self.outputLabel.setPixmap(pixmap)


if __name__ == "__main__":

    app = QApplication(sys.argv)
    window = Window()
    window.show()
    sys.exit(app.exec_())
