/****************************************************************************
**
** Copyright (C) 2007 Trolltech ASA. All rights reserved.
**
** This file is part of the documentation of Qt. It was originally
** published as part of Qt Quarterly.
**
** This file may be used under the terms of the GNU General Public License
** version 2.0 as published by the Free Software Foundation or under the
** terms of the Qt Commercial License Agreement. The respective license
** texts for these are provided with the open source and commercial
** editions of Qt.
**
** If you are unsure which license is appropriate for your use, please
** review the following information:
** http://www.trolltech.com/products/qt/licensing.html or contact the
** sales department at sales@trolltech.com.
**
** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
**
****************************************************************************/

#include <QtGui>
#include <QHttp>
#include "window.h"

Window::Window(QWidget *parent)
    : QWidget(parent)
{
    http = new QHttp(this);

    connect(http, SIGNAL(done(bool)),
            this, SLOT(updateForm(bool)));

    outputLabel = new QLabel;
    outputLabel->setFrameShape(QFrame::StyledPanel);
    equationEditor = new QTextEdit;

    QDialogButtonBox *buttonBox = new QDialogButtonBox;
    clearButton = buttonBox->addButton(
        tr("&Clear"), QDialogButtonBox::ResetRole);
    updateButton = buttonBox->addButton(
        tr("&Update"), QDialogButtonBox::ApplyRole);

    connect(clearButton, SIGNAL(clicked()),
            this, SLOT(clearForm()));
    connect(updateButton, SIGNAL(clicked()),
            this, SLOT(fetchImage()));

    QVBoxLayout *layout = new QVBoxLayout;
    layout->setMargin(4);
    layout->setSpacing(4);
    layout->addWidget(outputLabel, 1);
    layout->addWidget(equationEditor);
    layout->addWidget(buttonBox);
    setLayout(layout);

    setWindowTitle(tr("MathTran Equation Viewer"));
}

void Window::clearForm()
{
    outputLabel->setPixmap(QPixmap());
    equationEditor->clear();
}

void Window::fetchImage()
{
    clearButton->setEnabled(false);
    updateButton->setEnabled(false);
    equationEditor->setReadOnly(true);

    QUrl url;
    url.setPath("/cgi-bin/mathtran");
    url.setQueryDelimiters('=', ';');
    url.addQueryItem("D", "3");
    url.addQueryItem("tex", QUrl::toPercentEncoding(
                     equationEditor->toPlainText()));

    http->setHost("mathtran.org");
    http->get(url.toString());
}

void Window::updateForm(bool error)
{
    if (!error) {
        QImage image;
        if (image.loadFromData(http->readAll())) {
            QPixmap pixmap = QPixmap::fromImage(image);
            outputLabel->setPixmap(pixmap);
        }
    }

    clearButton->setEnabled(true);
    updateButton->setEnabled(true);
    equationEditor->setReadOnly(false);
}
